@@ -28,7 +28,7 @@ namespace igl
         typename DerivedF
         >
       IGL_INLINE void lexicographic_triangulation(
-          const Eigen::PlainObjectBase<DerivedP>& P,
+          const Eigen::MatrixBase<DerivedP>& P,
           Eigen::PlainObjectBase<DerivedF>& F);
     }
   }
