@@ -27,9 +27,9 @@ namespace igl
     typename DerivedO>
   IGL_INLINE bool writeBF(
     const std::string & filename,
-    const Eigen::PlainObjectBase<DerivedWI> & WI,
-    const Eigen::PlainObjectBase<DerivedP> & P,
-    const Eigen::PlainObjectBase<DerivedO> & O);
+    const Eigen::MatrixBase<DerivedWI> & WI,
+    const Eigen::MatrixBase<DerivedP> & P,
+    const Eigen::MatrixBase<DerivedO> & O);
 }
 
 #ifndef IGL_STATIC_LIBRARY
